==> minty-2.0.0.crate: minty-2.0.0/README.md <==
# minty

Project Minty has a new look and feel!!! 

<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/163739271-81e09254-d7b5-4710-83f9-453cfcfb8b9a.png">


Minty is a superb file deduplication app built in rust with a rust user interface. I say superb because it is rust on rust!.

Minty uses parrellism for a speedy and safe deduplication search.  The app reads the content of each file and then compares the content to other, making for a truly reliable app.

The app searches and compares each individual file. Free up space by removing unwanted files.  
 
<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/163739084-cb9c37ac-442c-49f0-8547-366848c51c32.gif">
 
<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/163004655-e4ab6314-6010-45c0-984c-8b412cdfdc89.gif">
 
You can view all duplicate files and batch delete them for each file collection. No more having to delete one file at time!

<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/163003275-0b4ed1f3-25bd-470a-abf2-77b312fc67d0.gif">

## Installation
#### Hombebrew
```
brew tap mjehrhart/minty
brew install/minty/minty
```

#### Upgrade
```
brew update
brew upgrade mjehrhart/minty/minty
```
or

```
brew uninstall mjehrhart/minty/minty
brew install mjehrhart/minty/minty
```

This app is free to use and is a work in progress.   

If you have any question, comments, or concerns please visit here:  
https://github.com/mjehrhart/minty/discussions

==> minty-2.0.3.crate: minty-2.0.3/README.md <==
# minty
 
Project Minty has a new look and feel!!! 

<img width="50%" alt="minty2 0 1_1c" src="https://user-images.githubusercontent.com/97703291/164116890-d50354a0-9eef-49e9-b118-d83f0579975c.gif">
 
Minty is an amazingly fast file deduplication app built in rust with a rust user interface. I say superb because it is rust on rust!.

Minty uses parrellism for a speedy and safe deduplication search. The app hashes the first (nth) bytes of each file to allow for direct comparisions, making for a truly reliable app.

The app searches and compares each individual file. Free up space by removing unwanted files. 
 
<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/164116898-9da83abf-0f72-43bc-a2ca-ccc1de8e3a33.gif">
 
Old Look and Feel  

<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/163004655-e4ab6314-6010-45c0-984c-8b412cdfdc89.gif">
 
You can view all duplicate files and batch delete them for each file collection. No more having to delete one file at time!

<img width="50%" alt="Screen Shot Minty" src="https://user-images.githubusercontent.com/97703291/163003275-0b4ed1f3-25bd-470a-abf2-77b312fc67d0.gif">

## Installation
#### Hombebrew
```
brew tap mjehrhart/minty
brew install mjehrhart/minty/minty
```

#### Upgrade
```
brew update
brew upgrade mjehrhart/minty/minty
```
or

```
brew uninstall mjehrhart/minty/minty
brew install mjehrhart/minty/minty
```

This app is free to use and is a work in progress.   

If you have any question, comments, or concerns please visit here:  
https://github.com/mjehrhart/minty/discussions
